#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAXNUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAXNUM_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/maxnum.hpp>

#endif
